# npc_lims

**n**euro**p**ixels **c**loud **lims**
	
Tools to fetch and update paths, metadata and state for Mindscope Neuropixels sessions, in the cloud.   

[![Python
Versions](https://img.shields.io/pypi/pyversions/npc_lims.svg)](https://pypi.python.org/pypi/npc-lims/)
## quickstart

```bash
pip install npc_lims
```

